==> tabslet-1.7.1.tgz: package/README.md <==
# Tabslet

[![npm version](https://badge.fury.io/js/tabslet.png)](http://badge.fury.io/js/tabslet)
[![Bower version](https://badge.fury.io/bo/Tabslet.png)](http://badge.fury.io/bo/Tabslet)

Yet another jQuery plugin for tabs, lightweight, easy to use and with some extra features

* [Demonstration page][1]
* [Documentation (wiki)][3]

## Features

Beyond the standard tabs functionality:

* Flexible HTML structure
* Custom events
* Data attribute initialization and configuration
* Controls (next, previous)
* Rotation (usefull for banner rotators/carousels)
* Deep linking support
* Change tabs on mouse over
* Use animation effect for tabs' changing
* Ability to use either _href_ or _alt_ attribute to target tab
* Destroy and control (next, prev, show) methods

## Compatibility/Dependencies

Compatible with IE7+, Chrome, Firefox, Safari
and jQuery 1.8.x, 1.9.x, 1.11.x, 2.1.x.

No additional dependencies are required.

## Questions/Answers and Enhancements

Do you have any questions? First, take a look [here][6].

Or if you are looking for enhancements, [here][7].

## Credits
* [Stevy.gr][4]
* [PVgr][5]

## Copyright and license

Copyright 2015 Dimitris Krestos

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

[http://www.apache.org/licenses/LICENSE-2.0][2]

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

  [1]: http://vdw.github.io/Tabslet/
  [2]: http://www.apache.org/licenses/LICENSE-2.0
  [3]: https://github.com/vdw/Tabslet/wiki
  [4]: http://stevy.gr/
  [5]: http://www.pvgr.eu/en/
  [6]: https://github.com/vdw/Tabslet/issues?utf8=%E2%9C%93&q=label%3Aquestion
  [7]: https://github.com/vdw/Tabslet/issues?utf8=%E2%9C%93&q=label%3Aenhancement

==> tabslet-1.7.2.tgz: package/README.md <==
# Tabslet

[![npm version](https://badge.fury.io/js/tabslet.png)](http://badge.fury.io/js/tabslet)
[![Bower version](https://badge.fury.io/bo/Tabslet.png)](http://badge.fury.io/bo/Tabslet)

Yet another jQuery plugin for tabs, lightweight, easy to use and with some extra features

* [Demonstration page][1]
* [Documentation (wiki)][3]

## Features

Beyond the standard tabs functionality:

* Flexible HTML structure
* Custom events
* Data attribute initialization and configuration
* Controls (next, previous)
* Rotation (usefull for banner rotators/carousels)
* Deep linking support
* Change tabs on mouse over
* Use animation effect for tabs' changing
* Ability to use either _href_ or _alt_ attribute to target tab
* Destroy and control (next, prev, show) methods

## Compatibility/Dependencies

Compatible with IE7+, Chrome, Firefox, Safari
and jQuery 1.8.x, 1.9.x, 1.11.x, 1.12.x, 2.1.x, 2.2.x.

No additional dependencies are required.

## Questions/Answers and Enhancements

Do you have any questions? First, take a look [here][6].

Or if you are looking for enhancements, [here][7].

## Credits
* [Stevy.gr][4]
* [PVgr][5]

## Copyright and license

Copyright 2015 Dimitris Krestos

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

[http://www.apache.org/licenses/LICENSE-2.0][2]

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

  [1]: http://vdw.github.io/Tabslet/
  [2]: http://www.apache.org/licenses/LICENSE-2.0
  [3]: https://github.com/vdw/Tabslet/wiki
  [4]: http://stevy.gr/
  [5]: http://www.pvgr.eu/en/
  [6]: https://github.com/vdw/Tabslet/issues?utf8=%E2%9C%93&q=label%3Aquestion
  [7]: https://github.com/vdw/Tabslet/issues?utf8=%E2%9C%93&q=label%3Aenhancement
